@if (@CodeSection == @Batch) @then

@echo off
setlocal
@rem *************************************************************************
@rem
@rem BalabolkaStart.js.bat: Start Balabolka for clipboard or file
@rem
@rem Copyright (c) 2015-2019 Hans Schmidts
@rem
@rem $Revision: 1.2 $
@rem $Date: 2020/03/25 10:06:49 $
@rem $Source: /BSK/BSK_PRJ/scripts/UTIL/BalabolkaStart.js.bat,v $
@rem
@rem History:
@rem V1.2  2019-04-07  HS
@rem - Use [BSK_TU_BASE_DIR] or "[Drive]:\BSK\Tools",  "[Drive]:\BSK\UTIL"
@rem V1.1  2015-04-03  HS
@rem - Initial revision
@rem
@rem *************************************************************************
set _del_file_=0
set _opt_=
:optloop
if ''== '%1' goto optend
if /I "%~1"=="/NOP" (
  set NOPAUSE=1
) else if /I "%~1"=="/M" (
  set _opt_=%_opt_% -m
) else if /I "%~1"=="/q" (
  set _opt_=%_opt_% -q
) else (
  goto optend
)
shift /1
goto optloop
:optend
if '/?'=='%1' goto help
if '-?'=='%1' goto help
if not ''=='%2' goto help
goto start
:help
  @echo BalabolkaStart.js.bat: Start Balabolka for clipboard or file
  @echo Usage: BalabolkaStart.js.bat [options] [file]
  @echo or     drag and drop or sendto file to this batch
  @echo Options:
  @echo   /m: Start Balabolka minimized
  @echo   /noP: No pause
  @echo   /q: Quit Balabolka after read of the text
  @echo Notes:
  @echo - If no file is given then clipboard is copied to a temp. file for
  @echo   reading (not clipboard direct so you can see the text).
  @echo - Use link in QuickLaunch and click to read clipboard content or drag a
  @echo   text file (incl. doc, epub etc.) to read that file.
  @echo - Set icon for link to icon of balabolka.exe.
  @echo - This script also serves as example for clipboard access from batch.
  goto errlevelp

@rem *************************************************************************
:start
set "_name_=%~1"
if not "%~1"=="" goto doit

if not "%KEEP_TEMP%"=="1" set _del_file_=1
set "_name_=%DATE%_%TIME%"
set "_name_=%_name_:/=_%"
set "_name_=%_name_: =_%"
set "_name_=%_name_:\=_%"
set "_name_=%_name_:,=_%"
set "_name_=%_name_::=_%"
set "_name_=%TEMP%\~%~n0_%_name_%.txt"
if exist "%_name_%" erase /f /q "%_name_%" >nul 2>&1
cscript /nologo /e:JScript "%~f0" "%_name_%"
@rem Note: One-liner with stdout see "TypeClipboardContent.js.bat", but stdout
@rem is OEM encoded, so we must write to file in JScript (not redirect stdout).

:doit
if not exist "%_name_%" (
  @echo ?%~nx0: "%_name_%" not found
  goto errlevelp
)
for %%N in ("%_name_%") do (
  if "%%~zN"=="0" (
    @echo ?%~nx0: Empty file "%_name_%"
    goto err_era
  )
)
set _balabolka_exe=
for %%N in (balabolka.exe) do if exist "%%~f$PATH:N" set "_balabolka_exe=%%~f$PATH:N"
if not "%_balabolka_exe%"=="" goto balabolka
for %%V in ("%~d0" "C:" "D:" %BSK_TU_BASE_DIR%) do (
  for /D %%D in ("%%~V\Tools\Balabolka*" "%%~V\BSK\Tools\Balabolka*" ^
                 "%%~V\Tool\Balabolka*" "%%~V\Program Files\Balabolka*" ^
                 "%%~V\Program Files (x86)\Balabolka*" ^
                 "%%~V\Programme\Balabolka*") do (
    if exist "%%~D\balabolka.exe" (
      set "_balabolka_exe=%%~D\balabolka.exe"
      goto balabolka
    )
  )
)
@echo ?%~nx0: "balabolka.exe" not found
:err_era
if "%_del_file_%"=="1" erase /f /q "%_name_%" >nul 2>&1
goto errlevelp

:balabolka
@echo %~nx0: Start "balabolka.exe" ...
start "" /B /WAIT "%_balabolka_exe%" %_opt_% -r "%_name_%"
if "%_del_file_%"=="1" erase /f /q "%_name_%" >nul 2>&1
@echo %~nx0: Done
ping -n 3 127.0.0.1 >nul 2>&1
exit /b 0

:errlevelp
if not "%NOPAUSE%"=="" ping -n 3 127.0.0.1 >nul 2>&1
if     "%NOPAUSE%"=="" pause
exit /b 1

@end // begin JScript hybrid chimera
var oFileSys = WSH.CreateObject("scripting.filesystemobject");
var fiOut = oFileSys.CreateTextFile(WScript.Arguments(0), true);
fiOut.Write(WSH.CreateObject('htmlfile').parentWindow.clipboardData.getData('text'));
fiOut.Close();
// eof
